@@ -11,11 +11,11 @@ Math::DWT - Pure Perl 1-D Discrete Wavelet Transform.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -24,7 +24,7 @@ This module computes the forward and inverse Discrete Wavelet Transform using ar
 
     use Math::DWT;
 
-    my $dwt = Math::DWT->new('Daubechies',4);
+    my $dwt = Math::DWT->new('Daubechies',1); # Haar
 
     my @x = qw/8 6 7 5 3 0 9 0/; # zero-pad input to make it 2^n long
 
@@ -132,6 +132,9 @@ sub dwt {
 		($lo_tmp,$hi_tmp[$j-1])=afb($lo_tmp,$lo,$hi);
 	};
 	$hi_tmp[$level]=$lo_tmp;
+	if (wantarray()) {
+		return @hi_tmp;
+	};
 	return \@hi_tmp;
 
 }
