@@ -1,4 +1,6 @@
 package Math::DWT::Wavelet::Symlet;
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -6,11 +8,11 @@ Math::DWT::Wavelet::Symlet - FIR lo- & hi-pass filter coefficients for the Symle
 
 =head1 VERSION
 
-Version 0.01_1
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01_1';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
